@@ -27,6 +27,9 @@ use constant INSTALLER_SAMPLE
                             => 'CPANPLUS::Dist::Sample';
 use constant INSTALLER_BASE => 'CPANPLUS::Dist::Base';                            
 
+use constant SHELL_DEFAULT  => 'CPANPLUS::Shell::Default';
+use constant SHELL_CLASSIC  => 'CPANPLUS::Shell::Classic';
+
 use constant CONFIG         => 'CPANPLUS::Config';
 use constant CONFIG_USER    => 'CPANPLUS::Config::User';
 use constant CONFIG_SYSTEM  => 'CPANPLUS::Config::System';
@@ -207,6 +210,8 @@ use constant CHECKSUMS      => 'CHECKSUMS';
 use constant PGP_HEADER     => '-----BEGIN PGP SIGNED MESSAGE-----';
 use constant ENV_CPANPLUS_CONFIG
                             => 'PERL5_CPANPLUS_CONFIG';
+use constant ENV_CPANPLUS_IS_EXECUTING
+                            => 'PERL5_CPANPLUS_IS_EXECUTING';
 use constant DEFAULT_EMAIL  => 'cpanplus@example.com';   
 use constant CPANPLUS_UA    => sub { ### for the version number ###
                                      require CPANPLUS::Internals;
