@@ -134,11 +134,16 @@ CPANPLUS::Selfupdate
             signature => [
                 sub {
                     my $cb      = shift;
-                    return if can_run('gpg') and 
-                        $cb->configure_object->get_conf('prefer_bin');
+                    return if can_run('gpg');
+                        ### leave this out -- Crypt::OpenPGP is fairly
+                        ### painful to install, and broken on some platforms
+                        ### so we'll just always fall back to gpg. It may
+                        ### issue a warning or 2, but that's about it.
+                        ### this change due to this ticket: #26914
+                        # and $cb->configure_object->get_conf('prefer_bin');
                     return { 'Crypt::OpenPGP' => '0.0' };
                 },            
-                sub { 
+                sub {
                     my $cb = shift;
                     return $cb->configure_object->get_conf('signature');
                 },
@@ -218,7 +223,7 @@ sub selfupdate {
         latest  => { default  => 0, store => \$latest,    allow => BOOLEANS },                     
         force   => { default => $conf->get_conf('force'), store => \$force },
     };
-    
+        
     check( $tmpl, \%hash ) or return;
     
     my $ref     = $cache->{$type};
@@ -229,7 +234,7 @@ sub selfupdate {
     ### do we need the latest versions?
     @mods       = $latest 
                     ? @mods 
-                    : grep { $_->is_installed_version_sufficient } @mods;
+                    : grep { !$_->is_installed_version_sufficient } @mods;
     
     my $flag;
     for my $mod ( @mods ) {
